get_last_block_number
=====================

.. code-block:: python

    get_last_block_number() -> int

Retrieves the number of the latest block in the blockchain.

Example:

.. code-block:: python

    last_block_number = await btc_client.get_last_block_number()

